Thanks
======

To everyone who has contributed to this project, thanks for your help!

Attribution
===========
* The URL shortening code, `shorturl.py`, was [written](http://snipplr.com/view/40257/) by **ksaver**.  It's in the Public Domain.
* The HTML-stripping code, `MLStripper.py`, was originally [written](http://stackoverflow.com/questions/753052/strip-html-from-strings-in-python) by **Eloff**.
* The filtering of public notes code was originally written by **sazius**.
* **strugee** made various improvements, including forcing python2, using PyPump's login capabilities better, and improved URL handling.
